==> haskell-unicode-transforms-0.4.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-transforms
version:              0.4.0
visibility:           public
id:                   unicode-transforms-0.4.0-4ZIl5C5QolBHJO9OE8PwFR
key:                  unicode-transforms-0.4.0-4ZIl5C5QolBHJO9OE8PwFR
license:              BSD-3-Clause
copyright:
    2016-2017 Harendra Kumar,
    2014–2015 Antonio Nikishaev

maintainer:           harendra.kumar@gmail.com
author:               Harendra Kumar
stability:            Experimental
homepage:             http://github.com/composewell/unicode-transforms
synopsis:             Unicode normalization
description:
    Fast Unicode 14.0.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).

category:             Data,Text,Unicode
abi:                  d23960a737ee40be1c2f190d0b45fe33
exposed:              True
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types

hidden-modules:       Data.Unicode.Internal.NormalizeStream
import-dirs:          /usr/lib/ghc-9.0.2/site-local/unicode-transforms-0.4.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unicode-transforms-0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/unicode-transforms-0.4.0
hs-libraries:         HSunicode-transforms-0.4.0-4ZIl5C5QolBHJO9OE8PwFR
depends:
    base-4.15.1.0 bytestring-0.10.12.1 ghc-prim-0.7.0 text-1.2.5.0
    unicode-data-0.2.0-9yR4Jebfm1qAXqi9KwKkrR

haddock-interfaces:
    /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock

haddock-html:         /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-transforms-0.4.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-transforms
version:              0.4.0
visibility:           public
id:                   unicode-transforms-0.4.0-AHaRv9LGi6gC0D3HmsRS7L
key:                  unicode-transforms-0.4.0-AHaRv9LGi6gC0D3HmsRS7L
license:              BSD-3-Clause
copyright:
    2016-2017 Harendra Kumar,
    2014–2015 Antonio Nikishaev

maintainer:           harendra.kumar@gmail.com
author:               Harendra Kumar
stability:            Experimental
homepage:             http://github.com/composewell/unicode-transforms
synopsis:             Unicode normalization
description:
    Fast Unicode 14.0.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).

category:             Data,Text,Unicode
abi:                  7b56c0fc6d4cf085ee9e6ac70d0610b0
exposed:              True
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types

hidden-modules:       Data.Unicode.Internal.NormalizeStream
import-dirs:          /usr/lib/ghc-9.0.2/site-local/unicode-transforms-0.4.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unicode-transforms-0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/unicode-transforms-0.4.0
hs-libraries:         HSunicode-transforms-0.4.0-AHaRv9LGi6gC0D3HmsRS7L
depends:
    base-4.15.1.0 bytestring-0.10.12.1 ghc-prim-0.7.0 text-1.2.5.0
    unicode-data-0.2.0-9yR4Jebfm1qAXqi9KwKkrR

haddock-interfaces:
    /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock

haddock-html:         /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
